# microfading
Package to manipulate microfading data


Main features
-------------

- **Visualisation of microfading data**.

- **Queries on data and metadata**.

- **Mathematical operations on microfading data**: average, extrapolation, delta values, interpolation.


Installation or upgrade
-----------------------

To install `microfading`, use::

     pip install microfading

To upgrade from an older version, use::

     pip install --upgrade microfading

Further details are in the `on-line documentation
<https://g-patin.github.io/microfading/>`_.
